diff --git a/contrib/dist/make-html-man-pages.pl b/contrib/dist/make-html-man-pages.pl
index 616ecf6958..d637663805 100755
--- a/contrib/dist/make-html-man-pages.pl
+++ b/contrib/dist/make-html-man-pages.pl
@@ -2,8 +2,8 @@
#
# Copyright (c) 2010 Cisco Systems, Inc.
#
-# Script to generate PHP-ized files of man pages generated by Open MPI
-# tarballs.
+# Script to generate PHP-ized files of Open MPI tarball-installed man
+# pages.
#
use strict;
@@ -11,16 +11,16 @@ use File::Find;
use File::Basename;
use Cwd;
-my $topdir;
+my $mandir;
my $version;
# Read command line arguments
while (@ARGV) {
my $a = $ARGV[0];
- if ($a eq "--topdir" && $#ARGV >= 1) {
+ if ($a eq "--mandir" && $#ARGV >= 1) {
shift @ARGV;
- $topdir = $ARGV[0];
- print "Found topdir: $topdir\n";
+ $mandir = $ARGV[0];
+ print "Found mandir: $mandir\n";
shift @ARGV;
}
@@ -33,8 +33,8 @@ while (@ARGV) {
}
# Check that we have what we need
-if (!defined($topdir) || !defined($version)) {
- print "Usage: $0 --topdir dir --version version\n";
+if (!defined($mandir) || !defined($version)) {
+ print "Usage: $0 --mandir dir --version version\n";
exit(1);
}
@@ -42,15 +42,15 @@ if (!defined($topdir) || !defined($version)) {
my @files;
my $pwd = Cwd::cwd();
# Find all *.[0-9] files in the $topdir/share/man tree.
&File::Find::find(
sub {
push(@files, $File::Find::name) if (-f $_ && $_ =~ /\.[1-9]$/);
- }, "$topdir/share/man");
+ }, $mandir);
-# Must cd into the "man" directory because some of the man pages refer
-# to other man pages by "man/
@@ -42,15 +42,15 @@ if (!defined($topdir) || !defined($version)) {
my @files;
my $pwd = Cwd::cwd();
-# Find all *.[0-9] files in the $topdir/share/man tree.
+# Find all *.[0-9] files in the $mandir tree.
&File::Find::find(
sub {